@@ -21,19 +21,40 @@
 #'      facet_wrap(~am) +
 #'      ggtitle('Diamond Prices')
 #' p + scale_colour_wsj('colors6', '') + theme_wsj()
-#' # Use a gray background instead#' 
+#' # Use a gray background instead#'
 #' p + scale_colour_wsj('colors6', '') + theme_wsj(color = "gray")
 #' @export
-theme_wsj <- function(base_size = 12, color = "brown", base_family = "sans", title_family = "mono") {
+theme_wsj <- function(base_size = 12,
+                      color = "brown",
+                      base_family = "sans",
+                      title_family = "mono") {
   colorhex <- ggthemes_data$wsj$bg[color]
-  (theme_foundation(base_size = base_size, base_family = base_family) + theme(line = element_line(linetype = 1, colour = "black"), 
-    rect = element_rect(fill = colorhex, linetype = 0, colour = NA), text = element_text(colour = "black"), title = element_text(family = title_family, 
-      size = rel(2)), axis.title = element_blank(), axis.text = element_text(face = "bold", size = rel(1)), axis.text.x = element_text(colour = NULL), 
-    axis.text.y = element_text(colour = NULL), axis.ticks = element_line(colour = NULL), axis.ticks.y = element_blank(), 
-    axis.ticks.x = element_line(colour = NULL), axis.line = element_line(), axis.line.y = element_blank(), legend.background = element_rect(), 
-    legend.position = "top", legend.direction = "horizontal", legend.box = "vertical", panel.grid = element_line(colour = NULL, 
-      linetype = 3), panel.grid.major = element_line(colour = "black"), panel.grid.major.x = element_blank(), panel.grid.minor = element_blank(), 
-    plot.title = element_text(hjust = 0, face = "bold"), plot.margin = unit(c(1, 1, 1, 1), "lines"), strip.background = element_rect()))
+  (theme_foundation(base_size = base_size, base_family = base_family) +
+    theme(line = element_line(linetype = 1, colour = "black"),
+          rect = element_rect(fill = colorhex, linetype = 0, colour = NA),
+          text = element_text(colour = "black"),
+          title = element_text(family = title_family,
+                               size = rel(2)),
+          axis.title = element_blank(),
+          axis.text = element_text(face = "bold", size = rel(1)),
+          axis.text.x = element_text(colour = NULL),
+          axis.text.y = element_text(colour = NULL),
+          axis.ticks = element_line(colour = NULL),
+          axis.ticks.y = element_blank(),
+          axis.ticks.x = element_line(colour = NULL),
+          axis.line = element_line(),
+          axis.line.y = element_blank(),
+          legend.background = element_rect(),
+          legend.position = "top",
+          legend.direction = "horizontal",
+          legend.box = "vertical",
+          panel.grid = element_line(colour = NULL, linetype = 3),
+          panel.grid.major = element_line(colour = "black"),
+          panel.grid.major.x = element_blank(),
+          panel.grid.minor = element_blank(),
+          plot.title = element_text(hjust = 0, face = "bold"),
+          plot.margin = unit(c(1, 1, 1, 1), "lines"),
+          strip.background = element_rect()))
 }
 
 #' Wall Street Journal color palette (discrete)
@@ -49,11 +70,17 @@ theme_wsj <- function(base_size = 12, color = "brown", base_family = "sans", tit
 #' The following palettes are defined,
 #'
 #' \describe{
-#' \item{rgby}{Red/Green/Blue/Yellow theme. Examples: \url{http://twitpic.com/b2e3v2}.}
-#' \item{green_red}{Green/red two-color scale for good/bad. Examples: \url{http://twitpic.com/b1avj6}, \url{http://twitpic.com/a4kxcl}.}
-#' \item{green_black}{Black-green 4-color scale for 'Very negative', 'Somewhat negative', 'somewhat positive', 'very positive'. Examples: \url{http://twitpic.com/awbua0}.}
-#' \item{dem_rep}{Democrat/Republican/Undecided blue/red/gray scale. Examples: \url{http://twitpic.com/awbua0}.}
-#' \item{colors6}{Red,blue,gold,green,orange, and black palette. Examples: \url{http://twitpic.com/9gfg5q}.}
+#' \item{rgby}{Red/Green/Blue/Yellow theme.
+#' Examples: \url{http://twitpic.com/b2e3v2}.}
+#' \item{green_red}{Green/red two-color scale for good/bad. Examples:
+#' \url{http://twitpic.com/b1avj6}, \url{http://twitpic.com/a4kxcl}.}
+#' \item{green_black}{Black-green 4-color scale for 'Very negative',
+#' 'Somewhat negative', 'somewhat positive', 'very positive'.
+#' Examples: \url{http://twitpic.com/awbua0}.}
+#' \item{dem_rep}{Democrat/Republican/Undecided blue/red/gray scale.
+#' Examples: \url{http://twitpic.com/awbua0}.}
+#' \item{colors6}{Red, blue, gold, green, orange, and black palette.
+#' Examples: \url{http://twitpic.com/9gfg5q}.}
 #' }
 #'
 #' @param palette \code{character} The color palette to use. This
@@ -94,5 +121,3 @@ scale_color_wsj <- scale_colour_wsj
 scale_fill_wsj <- function(palette = "colors6", ...) {
   discrete_scale("fill", "wsj", wsj_pal(palette), ...)
 }
-
- 
